=====================
Software Requirements
=====================

This is the Software Requirements Specification.


Software capabilities
=====================


Saying hello
------------
.. item:: SRS_0001 Software saying hello
   :fulfills: SYS_0001

   The system will say hello, as stated in :item:`SYS_0001`


Saying goodbye
--------------
.. item:: SRS_0002 Software saying goodbye
   :fulfills: SYS_0002

   The systems will say goodbye

